@@ -3,16 +3,15 @@ import re
 
 from cfn_flip import to_yaml
 from stringcase import camelcase, pascalcase
-
-from troposphere import (Base64, FindInMap, Output, Parameter, Ref, Sub, GetAtt,
-                         cloudformation, Export, Tags)
+from troposphere import (Base64, FindInMap, Output, Parameter, Ref, Sub,
+                         cloudformation, Export, GetAtt, Tags)
 from troposphere.autoscaling import (AutoScalingGroup, LaunchTemplateSpecification,
                                      ScalingPolicy)
 from troposphere.cloudwatch import Alarm, MetricDimension
 from troposphere.ec2 import (VPC, InternetGateway, NatGateway, Route,
                              RouteTable, SecurityGroup, Subnet,
                              SubnetRouteTableAssociation, VPCGatewayAttachment,SecurityGroupIngress,
-                              LaunchTemplateData, LaunchTemplate, IamInstanceProfile)
+                             LaunchTemplateData, LaunchTemplate, IamInstanceProfile, LaunchTemplateBlockDeviceMapping, EBSBlockDevice)
 from troposphere.ecs import Cluster
 from troposphere.elasticache import SubnetGroup as ElastiCacheSubnetGroup
 from troposphere.iam import InstanceProfile, Role
@@ -518,7 +517,7 @@ for cluster for 15 minutes.',
                     "/etc/dnsmasq.conf": cloudformation.InitFile(
                         content=Sub(
                             '\n'.join([
-                                '# Server Configuration'
+                                '# Server Configuration',
                                 'listen-address=127.0.0.1',
                                 'port=53',
                                 'bind-interfaces',
@@ -530,7 +529,7 @@ for cluster for 15 minutes.',
                                 'cache-size=500',
                                 'neg-ttl=60',
                                 'domain-needed',
-                                'bogus-priv'
+                                'bogus-priv',
                             ])
                         ),
                     )
@@ -587,7 +586,15 @@ for cluster for 15 minutes.',
             SecurityGroupIds=[GetAtt(self.sg_hosts, 'GroupId')],
             InstanceType=Ref('InstanceType'),
             ImageId=FindInMap("AWSRegionToAMI", Ref("AWS::Region"), "AMI"),
-            KeyName=Ref(self.key_pair)
+            KeyName=Ref(self.key_pair),
+            BlockDeviceMappings=[
+                LaunchTemplateBlockDeviceMapping(
+                    DeviceName="/dev/xvda",
+                    Ebs=EBSBlockDevice(
+                        VolumeType="gp3"
+                    )
+                )
+            ]
         )
         launch_template = LaunchTemplate(
             "LaunchTemplate",
